@@ -14,32 +14,33 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import List, Optional
+from __future__ import annotations
+
+from functools import cached_property
 
 import hvac
 from hvac.api.auth_methods import Kubernetes
 from hvac.exceptions import InvalidPath, VaultError
 from requests import Response
 
-from airflow.compat.functools import cached_property
 from airflow.utils.log.logging_mixin import LoggingMixin
 
-DEFAULT_KUBERNETES_JWT_PATH = '/var/run/secrets/kubernetes.io/serviceaccount/token'
+DEFAULT_KUBERNETES_JWT_PATH = "/var/run/secrets/kubernetes.io/serviceaccount/token"
 DEFAULT_KV_ENGINE_VERSION = 2
 
 
-VALID_KV_VERSIONS: List[int] = [1, 2]
-VALID_AUTH_TYPES: List[str] = [
-    'approle',
-    'aws_iam',
-    'azure',
-    'github',
-    'gcp',
-    'kubernetes',
-    'ldap',
-    'radius',
-    'token',
-    'userpass',
+VALID_KV_VERSIONS: list[int] = [1, 2]
+VALID_AUTH_TYPES: list[str] = [
+    "approle",
+    "aws_iam",
+    "azure",
+    "github",
+    "gcp",
+    "kubernetes",
+    "ldap",
+    "radius",
+    "token",
+    "userpass",
 ]
 
 
@@ -86,28 +87,28 @@ class _VaultClient(LoggingMixin):
 
     def __init__(
         self,
-        url: Optional[str] = None,
-        auth_type: str = 'token',
-        auth_mount_point: Optional[str] = None,
-        mount_point: str = "secret",
-        kv_engine_version: Optional[int] = None,
-        token: Optional[str] = None,
-        token_path: Optional[str] = None,
-        username: Optional[str] = None,
-        password: Optional[str] = None,
-        key_id: Optional[str] = None,
-        secret_id: Optional[str] = None,
-        role_id: Optional[str] = None,
-        kubernetes_role: Optional[str] = None,
-        kubernetes_jwt_path: Optional[str] = '/var/run/secrets/kubernetes.io/serviceaccount/token',
-        gcp_key_path: Optional[str] = None,
-        gcp_keyfile_dict: Optional[dict] = None,
-        gcp_scopes: Optional[str] = None,
-        azure_tenant_id: Optional[str] = None,
-        azure_resource: Optional[str] = None,
-        radius_host: Optional[str] = None,
-        radius_secret: Optional[str] = None,
-        radius_port: Optional[int] = None,
+        url: str | None = None,
+        auth_type: str = "token",
+        auth_mount_point: str | None = None,
+        mount_point: str | None = "secret",
+        kv_engine_version: int | None = None,
+        token: str | None = None,
+        token_path: str | None = None,
+        username: str | None = None,
+        password: str | None = None,
+        key_id: str | None = None,
+        secret_id: str | None = None,
+        role_id: str | None = None,
+        kubernetes_role: str | None = None,
+        kubernetes_jwt_path: str | None = "/var/run/secrets/kubernetes.io/serviceaccount/token",
+        gcp_key_path: str | None = None,
+        gcp_keyfile_dict: dict | None = None,
+        gcp_scopes: str | None = None,
+        azure_tenant_id: str | None = None,
+        azure_resource: str | None = None,
+        radius_host: str | None = None,
+        radius_secret: str | None = None,
+        radius_port: int | None = None,
         **kwargs,
     ):
         super().__init__()
@@ -173,14 +174,13 @@ class _VaultClient(LoggingMixin):
         it is still authenticated to Vault, and invalidates the cache if this
         is not the case.
 
-        :rtype: hvac.Client
         :return: Vault Client
 
         """
         if not self._client.is_authenticated():
             # Invalidate the cache:
             # https://github.com/pydanny/cached-property#invalidating-the-cache
-            self.__dict__.pop('_client', None)
+            self.__dict__.pop("_client", None)
         return self._client
 
     @cached_property
@@ -188,16 +188,15 @@ class _VaultClient(LoggingMixin):
         """
         Return an authenticated Hashicorp Vault client.
 
-        :rtype: hvac.Client
         :return: Vault Client
 
         """
         _client = hvac.Client(url=self.url, **self.kwargs)
         if self.auth_type == "approle":
             self._auth_approle(_client)
-        elif self.auth_type == 'aws_iam':
+        elif self.auth_type == "aws_iam":
             self._auth_aws_iam(_client)
-        elif self.auth_type == 'azure':
+        elif self.auth_type == "azure":
             self._auth_azure(_client)
         elif self.auth_type == "gcp":
             self._auth_gcp(_client)
@@ -223,11 +222,11 @@ class _VaultClient(LoggingMixin):
 
     def _auth_userpass(self, _client: hvac.Client) -> None:
         if self.auth_mount_point:
-            _client.auth_userpass(
+            _client.auth.userpass.login(
                 username=self.username, password=self.password, mount_point=self.auth_mount_point
             )
         else:
-            _client.auth_userpass(username=self.username, password=self.password)
+            _client.auth.userpass.login(username=self.username, password=self.password)
 
     def _auth_radius(self, _client: hvac.Client) -> None:
         if self.auth_mount_point:
@@ -302,14 +301,14 @@ class _VaultClient(LoggingMixin):
 
     def _auth_aws_iam(self, _client: hvac.Client) -> None:
         if self.auth_mount_point:
-            _client.auth_aws_iam(
+            _client.auth.aws.iam_login(
                 access_key=self.key_id,
                 secret_key=self.secret_id,
                 role=self.role_id,
                 mount_point=self.auth_mount_point,
             )
         else:
-            _client.auth_aws_iam(access_key=self.key_id, secret_key=self.secret_id, role=self.role_id)
+            _client.auth.aws.iam_login(access_key=self.key_id, secret_key=self.secret_id, role=self.role_id)
 
     def _auth_approle(self, _client: hvac.Client) -> None:
         if self.auth_mount_point:
@@ -326,7 +325,16 @@ class _VaultClient(LoggingMixin):
         else:
             _client.token = self.token
 
-    def get_secret(self, secret_path: str, secret_version: Optional[int] = None) -> Optional[dict]:
+    def _parse_secret_path(self, secret_path: str) -> tuple[str, str]:
+        if not self.mount_point:
+            split_secret_path = secret_path.split("/", 1)
+            if len(split_secret_path) < 2:
+                raise InvalidPath
+            return split_secret_path[0], split_secret_path[1]
+        else:
+            return self.mount_point, secret_path
+
+    def get_secret(self, secret_path: str, secret_version: int | None = None) -> dict | None:
         """
         Get secret value from the KV engine.
 
@@ -339,30 +347,29 @@ class _VaultClient(LoggingMixin):
 
         :return: secret stored in the vault as a dictionary
         """
+        mount_point = None
         try:
+            mount_point, secret_path = self._parse_secret_path(secret_path)
             if self.kv_engine_version == 1:
                 if secret_version:
                     raise VaultError("Secret version can only be used with version 2 of the KV engine")
-                response = self.client.secrets.kv.v1.read_secret(
-                    path=secret_path, mount_point=self.mount_point
-                )
+                response = self.client.secrets.kv.v1.read_secret(path=secret_path, mount_point=mount_point)
             else:
                 response = self.client.secrets.kv.v2.read_secret_version(
-                    path=secret_path, mount_point=self.mount_point, version=secret_version
+                    path=secret_path, mount_point=mount_point, version=secret_version
                 )
         except InvalidPath:
-            self.log.debug("Secret not found %s with mount point %s", secret_path, self.mount_point)
+            self.log.debug("Secret not found %s with mount point %s", secret_path, mount_point)
             return None
 
         return_data = response["data"] if self.kv_engine_version == 1 else response["data"]["data"]
         return return_data
 
-    def get_secret_metadata(self, secret_path: str) -> Optional[dict]:
+    def get_secret_metadata(self, secret_path: str) -> dict | None:
         """
         Reads secret metadata (including versions) from the engine. It is only valid for KV version 2.
 
         :param secret_path: The path of the secret.
-        :rtype: dict
         :return: secret metadata. This is a Dict containing metadata for the secret.
 
                  See https://hvac.readthedocs.io/en/stable/usage/secrets_engines/kv_v2.html for details.
@@ -370,17 +377,17 @@ class _VaultClient(LoggingMixin):
         """
         if self.kv_engine_version == 1:
             raise VaultError("Metadata might only be used with version 2 of the KV engine.")
+        mount_point = None
         try:
-            return self.client.secrets.kv.v2.read_secret_metadata(
-                path=secret_path, mount_point=self.mount_point
-            )
+            mount_point, secret_path = self._parse_secret_path(secret_path)
+            return self.client.secrets.kv.v2.read_secret_metadata(path=secret_path, mount_point=mount_point)
         except InvalidPath:
-            self.log.debug("Secret not found %s with mount point %s", secret_path, self.mount_point)
+            self.log.debug("Secret not found %s with mount point %s", secret_path, mount_point)
             return None
 
     def get_secret_including_metadata(
-        self, secret_path: str, secret_version: Optional[int] = None
-    ) -> Optional[dict]:
+        self, secret_path: str, secret_version: int | None = None
+    ) -> dict | None:
         """
         Reads secret including metadata. It is only valid for KV version 2.
 
@@ -389,27 +396,28 @@ class _VaultClient(LoggingMixin):
         :param secret_path: The path of the secret.
         :param secret_version: Specifies the version of Secret to return. If not set, the latest
             version is returned. (Can only be used in case of version 2 of KV).
-        :rtype: dict
         :return: The key info. This is a Dict with "data" mapping keeping secret
                  and "metadata" mapping keeping metadata of the secret.
         """
         if self.kv_engine_version == 1:
             raise VaultError("Metadata might only be used with version 2 of the KV engine.")
+        mount_point = None
         try:
+            mount_point, secret_path = self._parse_secret_path(secret_path)
             return self.client.secrets.kv.v2.read_secret_version(
-                path=secret_path, mount_point=self.mount_point, version=secret_version
+                path=secret_path, mount_point=mount_point, version=secret_version
             )
         except InvalidPath:
             self.log.debug(
                 "Secret not found %s with mount point %s and version %s",
                 secret_path,
-                self.mount_point,
+                mount_point,
                 secret_version,
             )
             return None
 
     def create_or_update_secret(
-        self, secret_path: str, secret: dict, method: Optional[str] = None, cas: Optional[int] = None
+        self, secret_path: str, secret: dict, method: str | None = None, cas: int | None = None
     ) -> Response:
         """
         Creates or updates secret.
@@ -423,7 +431,6 @@ class _VaultClient(LoggingMixin):
             allowed. If set to 0 a write will only be allowed if the key doesn't exist.
             If the index is non-zero the write will only be allowed if the key's current version
             matches the version specified in the cas parameter. Only valid for KV engine version 2.
-        :rtype: requests.Response
         :return: The response of the create_or_update_secret request.
 
                  See https://hvac.readthedocs.io/en/stable/usage/secrets_engines/kv_v1.html
@@ -434,12 +441,13 @@ class _VaultClient(LoggingMixin):
             raise VaultError("The method parameter is only valid for version 1")
         if self.kv_engine_version == 1 and cas:
             raise VaultError("The cas parameter is only valid for version 2")
+        mount_point, secret_path = self._parse_secret_path(secret_path)
         if self.kv_engine_version == 1:
             response = self.client.secrets.kv.v1.create_or_update_secret(
-                secret_path=secret_path, secret=secret, mount_point=self.mount_point, method=method
+                secret_path=secret_path, secret=secret, mount_point=mount_point, method=method
             )
         else:
             response = self.client.secrets.kv.v2.create_or_update_secret(
-                secret_path=secret_path, secret=secret, mount_point=self.mount_point, cas=cas
+                secret_path=secret_path, secret=secret, mount_point=mount_point, cas=cas
             )
         return response
