@@ -15,7 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Objects relating to sourcing connections & variables from Hashicorp Vault"""
+"""Objects relating to sourcing connections & variables from Hashicorp Vault."""
 from __future__ import annotations
 
 import warnings
@@ -169,7 +169,7 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
 
     def get_response(self, conn_id: str) -> dict | None:
         """
-        Get data from Vault
+        Get data from Vault.
 
         :return: The data from the Vault path if exists
         """
@@ -186,7 +186,7 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
 
     def get_conn_uri(self, conn_id: str) -> str | None:
         """
-        Get serialized representation of connection
+        Get serialized representation of connection.
 
         :param conn_id: The connection id
         :return: The connection uri retrieved from the secret
@@ -230,7 +230,7 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
 
     def get_variable(self, key: str) -> str | None:
         """
-        Get Airflow Variable
+        Get Airflow Variable.
 
         :param key: Variable Key
         :return: Variable Value retrieved from the vault
@@ -249,7 +249,7 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
 
     def get_config(self, key: str) -> str | None:
         """
-        Get Airflow Configuration
+        Get Airflow Configuration.
 
         :param key: Configuration Option Key
         :return: Configuration Option Value retrieved from the vault
